@@ -4,10 +4,10 @@
 #include "mobilepower.h"
 
 #include <KAboutData>
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KSharedConfig>
-#include <KConfigGroup>
 
 K_PLUGIN_CLASS_WITH_JSON(MobilePower, "powermanagement.json")
 
@@ -34,19 +34,19 @@ struct MobilePower::Private {
         FIVE_MINUTES,
         TEN_MINUTES,
         FIFTEEN_MINUTES,
-        NEVER
+        NEVER,
     };
 
     // Maps the indices of the timeValues indexes
     // to minutes.
-    QMap<int, qreal> idxToMinutes= {
+    QMap<int, qreal> idxToMinutes = {
         {THIRTY_SECONDS, 0.5},
         {ONE_MINUTE, 1},
         {TWO_MINUTES, 2},
         {FIVE_MINUTES, 5},
         {TEN_MINUTES, 10},
         {FIFTEEN_MINUTES, 15},
-        {NEVER, 0}
+        {NEVER, 0},
     };
 
     KSharedConfig::Ptr profilesConfig = KSharedConfig::openConfig("powermanagementprofilesrc", KConfig::SimpleConfig | KConfig::CascadeConfig);
@@ -216,7 +216,6 @@ void MobilePower::setLockScreenIdx(int idx)
         }
         d->suspendSessionTime = value;
         qDebug() << "SEtting to lock in " << value << "Minutes";
-
     }
     Q_EMIT suspendSessionIdxChanged();
     save();
@@ -268,7 +267,6 @@ int MobilePower::sleepScreenIdx()
         return MobilePower::Private::NEVER;
     }
 
-
     if (qFuzzyIsNull(d->sleepScreenTime)) {
         return MobilePower::Private::NEVER;
     } else if (qFuzzyCompare(d->sleepScreenTime, 0.5)) {
